@@ -62,7 +62,8 @@ class Clustering:
         @param membership: the membership list -- that is, the cluster
           index in which each element of the set belongs to.
         @param params: additional parameters to be stored in this
-          object's dictionary."""
+          object's dictionary.
+        """
         self._membership = list(membership)
         if len(self._membership) > 0:
             self._len = max(m for m in self._membership if m is not None) + 1
@@ -426,8 +427,11 @@ class VertexClustering(Clustering):
         @return: a copy of the largest cluster.
         """
         ss = self.sizes()
-        max_size = max(ss)
-        return self.subgraph(ss.index(max_size))
+        if ss:
+            max_size = max(ss)
+            return self.subgraph(ss.index(max_size))
+        else:
+            return self._graph.copy()
 
     def __plot__(self, backend, context, *args, **kwds):
         """Plots the clustering to the given Cairo context or matplotlib Axes.
@@ -573,7 +577,7 @@ class Dendrogram:
         if n is None:
             n = len(merges) + 1
         tuple_repr = range(n)
-        idxs = range(n)
+        idxs = list(range(n))
         for rowidx, row in enumerate(merges):
             i, j = row
             try:
@@ -584,7 +588,7 @@ class Dendrogram:
                 raise ValueError(
                     "malformed matrix, subgroup referenced "
                     + "before being created in step %d" % rowidx
-                )
+                ) from None
             idxs.append(j)
         return [x for x in tuple_repr if x is not None]
 
@@ -787,9 +791,7 @@ class VertexDendrogram(Dendrogram):
     """The dendrogram resulting from the hierarchical clustering of the
     vertex set of a graph."""
 
-    def __init__(
-        self, graph, merges, optimal_count=None, params=None, modularity_params=None
-    ):
+    def __init__(self, graph, merges, optimal_count=None, modularity_params=None):
         """Creates a dendrogram object for a given graph.
 
         @param graph: the graph that will be associated to the clustering
@@ -799,7 +801,6 @@ class VertexDendrogram(Dendrogram):
           clustering algorithm that produces the dendrogram. C{None} means
           that such a hint is not available; the optimal count will then be
           selected based on the modularity in such a case.
-        @param params: additional parameters to be stored in this object.
         @param modularity_params: arguments that should be passed to
           L{Graph.modularity} when the modularity is (re)calculated. If the
           original graph was weighted, you should pass a dictionary
@@ -1086,6 +1087,8 @@ class VertexCover(Cover):
         if clusters is None:
             clusters = [range(graph.vcount())]
 
+        self._resolve_names_in_clusters(graph, clusters)
+
         super().__init__(clusters, n=graph.vcount())
         if self._n > graph.vcount():
             raise ValueError(
@@ -1213,6 +1216,24 @@ class VertexCover(Cover):
             for cluster in self:
                 yield ", ".join(str(member) for member in cluster)
 
+    @staticmethod
+    def _resolve_names_in_clusters(graph, clusters):
+        if not graph.is_named():
+            return
+
+        names = graph.vs["name"]
+        name_to_index = {k: v for v, k in enumerate(names)}
+
+        for idx, cluster in enumerate(clusters):
+            if any(isinstance(item, str) for item in cluster):
+                new_cluster = []
+                for item in cluster:
+                    if isinstance(item, str):
+                        new_cluster.append(name_to_index.get(item, item))
+                    else:
+                        new_cluster.append(item)
+                clusters[idx] = new_cluster
+
 
 class CohesiveBlocks(VertexCover):
     """The cohesive block structure of a graph.
@@ -1438,6 +1459,24 @@ def _prepare_community_comparison(comm1, comm2, remove_none=False):
 def compare_communities(comm1, comm2, method="vi", remove_none=False):
     """Compares two community structures using various distance measures.
 
+    B{References}
+
+      - Meila M: Comparing clusterings by the variation of information. In:
+        Scholkopf B, Warmuth MK (eds). Learning Theory and Kernel Machines: 16th
+        Annual Conference on Computational Learning Theory and 7th Kernel
+        Workship, COLT/Kernel 2003, Washington, DC, USA. Lecture Notes in Computer
+        Science, vol. 2777, Springer, 2003. ISBN: 978-3-540-40720-1.
+      - Danon L, Diaz-Guilera A, Duch J, Arenas A: Comparing community structure
+        identification. I{J Stat Mech} P09008, 2005.
+      - van Dongen S: Performance criteria for graph clustering and Markov
+        cluster experiments. Technical Report INS-R0012, National Research
+        Institute for Mathematics and Computer Science in the Netherlands,
+        Amsterdam, May 2000.
+      - Rand WM: Objective criteria for the evaluation of clustering
+        methods. I{J Am Stat Assoc} 66(336):846-850, 1971.
+      - Hubert L and Arabie P: Comparing partitions. I{Journal of
+        Classification} 2:193-218, 1985.
+
     @param comm1: the first community structure as a membership list or
       as a L{Clustering} object.
     @param comm2: the second community structure as a membership list or
@@ -1457,23 +1496,6 @@ def compare_communities(comm1, comm2, method="vi", remove_none=False):
       are compared.
 
     @return: the calculated measure.
-    @newfield ref: Reference
-    @ref: Meila M: Comparing clusterings by the variation of information.
-          In: Scholkopf B, Warmuth MK (eds). Learning Theory and Kernel
-          Machines: 16th Annual Conference on Computational Learning Theory
-          and 7th Kernel Workship, COLT/Kernel 2003, Washington, DC, USA.
-          Lecture Notes in Computer Science, vol. 2777, Springer, 2003.
-          ISBN: 978-3-540-40720-1.
-    @ref: Danon L, Diaz-Guilera A, Duch J, Arenas A: Comparing community
-          structure identification. J Stat Mech P09008, 2005.
-    @ref: van Dongen D: Performance criteria for graph clustering and Markov
-          cluster experiments. Technical Report INS-R0012, National Research
-          Institute for Mathematics and Computer Science in the Netherlands,
-          Amsterdam, May 2000.
-    @ref: Rand WM: Objective criteria for the evaluation of clustering
-          methods. J Am Stat Assoc 66(336):846-850, 1971.
-    @ref: Hubert L and Arabie P: Comparing partitions. Journal of
-          Classification 2:193-218, 1985.
     """
     import igraph._igraph
 
@@ -1507,6 +1529,11 @@ def split_join_distance(comm1, comm2, remove_none=False):
     it is close to zero, then one of the partitions is close to being a
     subpartition of the other).
 
+    B{Reference}: van Dongen S: Performance criteria for graph clustering and
+    Markov cluster experiments. Technical Report INS-R0012, National Research
+    Institute for Mathematics and Computer Science in the Netherlands,
+    Amsterdam, May 2000.
+
     @param comm1: the first community structure as a membership list or
       as a L{Clustering} object.
     @param comm2: the second community structure as a membership list or
@@ -1521,11 +1548,6 @@ def split_join_distance(comm1, comm2, remove_none=False):
 
     @return: the projection distance of C{comm1} from C{comm2} and vice versa
       in a tuple. The split-join distance is the sum of the two.
-    @newfield ref: Reference
-    @ref: van Dongen D: Performance criteria for graph clustering and Markov
-          cluster experiments. Technical Report INS-R0012, National Research
-          Institute for Mathematics and Computer Science in the Netherlands,
-          Amsterdam, May 2000.
 
     @see: L{compare_communities()} with C{method = "split-join"} if you are
       not interested in the individual projection distances but only the
@@ -1599,5 +1621,7 @@ def _connected_components(graph, mode="strong"):
 
 def _clusters(graph, mode="strong"):
     """Deprecated alias to L{Graph.connected_components()}."""
-    deprecated("Graph.clusters() is deprecated; use Graph.connected_components() instead")
+    deprecated(
+        "Graph.clusters() is deprecated; use Graph.connected_components() instead"
+    )
     return graph.connected_components(mode=mode)
